package App::Nighttime;

use strict;
use warnings;
use vars '$VERSION';

$VERSION = "0.03";

use constant CONFIG_STEM => "/etc/nighttime/nighttime";

use Carp ();
use Config::Any 0.13;

sub new {
  my ($class, $options) = @_;
  my $self = {};

  $self->{config_stem} = $options->{config_stem} if defined $options->{config_stem};

  return bless($self, $class);
}

sub carp {
  shift;
  Carp::carp(@_);
}

sub croak {
  shift;
  Carp::croak(@_);
}

sub debug {
  my $self = shift;
  my $c    = $self->config;

  print STDERR @_, "\n" if $c->{debug};
}

sub config {
  my ($self) = @_;
  my $config_stem = $self->{config_stem} // CONFIG_STEM;

  return $self->{config} if defined $self->{config};

  my $configs = Config::Any->load_stems({
      stems   => [$config_stem],
      flatten_to_hash => 1,
      use_ext => 1,
      driver_args => {
          General => {
              -AutoTrue => 1,
          },
      },
  });
  my @configs = values %$configs;
  $self->croak("Not exactly one configuration file found.") unless @configs == 1;
  $self->{config} = $configs[0];

  return $self->{config};
}

sub version {
  return $VERSION;
}

sub _system {
  my $self = shift;
  if (system(@_) == 0) {
    return undef;
  }
  return "command '@_' failed: $?";
}

__END__
=head1 NAME

App::Nighttime - shutting down computer during nighttime

=head1 AUTHOR

Ansgar Burchardt

=cut
# vim: set et sw=2:
