package App::Nighttime::HostInfo::LDAP;

use strict;
use warnings;

use Carp;
use Net::LDAP;
use Net::LDAP::Util qw/escape_filter_value/;

use constant DEFAULT_FILTER => "(&(objectClass=ipHost)(objectClass=ieee802Device)(ipHostNumber=%s))";

sub new($$) {
  my ($class, $options) = @_;
  my $self = {};

  $self->{host} = $options->{host}
    or croak "No host specified.";
  $self->{bind} = $options->{bind} if exists $options->{bind};
  $self->{base} = $options->{base}
    or croak "No base DN specified.";
  $self->{filter} = $options->{filter} if defined $options->{filter};

  return bless $self, $class;
};

sub _ldap($) {
  my ($self) = @_;

  return $self->{ldap} if defined $self->{ldap};

  my $ldap = Net::LDAP->new($self->{host});
  my $mesg;
  if (defined $self->{bind}) {
    $mesg = $ldap->bind(%{ $self->{bind} });
  }
  else {
    $mesg = $ldap->bind;
  }
  $mesg->code && croak $mesg->error;

  $self->{ldap} = $ldap;
  return $self->{ldap};
}

sub ip_to_mac($$) {
  my ($self, $ip) = @_;

  my $ldap = $self->_ldap;
  my $escaped_ip = escape_filter_value($ip);

  my $filter_template = $self->{filter} // DEFAULT_FILTER;
  my $filter = sprintf $filter_template, $escaped_ip;

  my $mesg = $ldap->search(
    base      => $self->{base},
    scope     => "sub",
    filter    => $filter,
    sizelimit => 1,
    attrs     => ["macAddress"],
  );
  $mesg->code && croak $mesg->error;

  my $entry = $mesg->entry(0) or return undef;
  return $entry->get_value("macAddress");
}

1;
# vim: et sw=2:
